/***************************************************************************
** $Id: trayicon.cpp,v 1.3 2007/10/07 18:04:13 hoganrobert Exp $
 *   Copyright (C) 2005 by                                                 *
 *   Joris Guisson <joris.guisson@gmail.com>                               *
 *   Ivan Vasic <ivasic@gmail.com>                                         *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.             *
 ***************************************************************************/
#include <kpopupmenu.h>
#include <klocale.h>
#include <kapplication.h>
#include "trayicon.h"
#include <qtooltip.h>
#include <kpassivepopup.h>
#include <qstringlist.h>
#include "trayhoverpopup.h"
#include "torkconfig.h"


TrayIcon::TrayIcon( QWidget *parent, const char *name)
		: KSystemTray(parent, name)
{
	m_kt_pix = loadIcon("tork");
	setPixmap(m_kt_pix);
	paint=new QPainter( this );
	drawContents ( paint );
	
	m_hover_popup = new TrayHoverPopup(m_kt_pix,this);

	connect(this,SIGNAL(quitSelected()),kapp,SLOT(quit()));
	
	connect(this->contextMenu(),SIGNAL(aboutToShow()),m_hover_popup,SLOT(contextMenuAboutToShow()));
	connect(this->contextMenu(),SIGNAL(aboutToHide()),m_hover_popup,SLOT(contextMenuAboutToHide()));
}

TrayIcon::~TrayIcon()
{}

void TrayIcon::enterEvent(QEvent* ev)
{
	KSystemTray::enterEvent(ev);
	m_hover_popup->enterEvent();
}

void TrayIcon::leaveEvent(QEvent* )
{
	m_hover_popup->leaveEvent();
}

void TrayIcon::updateStats(const QString & downloadBandwidthHist, const QString & uploadBandwidthHist,
                           const QString & downloadBandwidth, const QString & uploadBandwidth,
                           const QStringList & serverReport, const QStringList & clientReport)
{

    QString serverStatus;
	for ( QStringList::ConstIterator it = serverReport.begin(); it != serverReport.end(); ++it )
	{
		if ((*it).isEmpty())
			continue;
        if ((it) != serverReport.begin())
            serverStatus.append(QString("<tr><td></td><td colspan='2'>%1</td></tr>").arg((*it)));
    }

	QString tip = i18n("<table cellpadding='2' cellspacing='2'align='center'>"
                        "<tr>"
                          "<td><b>Client:</b></td>"
                          "<td colspan='2'>%1</td>"
                        "</tr>")
                        .arg(*clientReport.begin());
    if (!TorkConfig::clientOnly()){
        tip.append(i18n("<tr>"
                          "<td><b>Server:</b></td>"
                          "<td colspan='2'>%1</td>"
                        "</tr>")
                        .arg(*serverReport.begin()));
    }
    tip.append(i18n(    "%1"
                        "<tr>"
                          "<td></td>"
                          "<td><b>BW Down</b></td>"
                          "<td><b>BW Up</b></td>"
                        "</tr>"
                        "<tr>"
                          "<td><b>Speed:</b></td>"
                          "<td><font color='#1c9a1c'>%2</font></td>"
                          "<td><font color='#990000'>%3</font></td>"
                        "</tr>"
                        "<tr>"
                          "<td><b>Total:</b></td>"
                          "<td><font color='#1c9a1c'>%4</font></td>"
                          "<td> <font color='#990000'>%5</font></td>"
                        "</tr>"
                        "</table>")
                        .arg(serverStatus)
                        .arg(downloadBandwidth)
                        .arg(uploadBandwidth)
                        .arg(downloadBandwidthHist)
                        .arg(uploadBandwidthHist));
	m_hover_popup->updateText(tip);
	
}


#include "trayicon.moc"
